# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from assisted_service_client.api_client import ApiClient


class EventsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def v2_list_events(self, **kwargs):  # noqa: E501
        """v2_list_events  # noqa: E501

        Lists events for a cluster.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v2_list_events(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cluster_id: The cluster to return events for.
        :param str host_id: A host in the specified cluster to return events for (DEPRECATED. Use `host_ids` instead).
        :param list[str] host_ids: Hosts in the specified cluster to return events for.
        :param str infra_env_id: The infra-env to return events for.
        :param int limit: The maximum number of records to retrieve.
        :param int offset: Number of records to skip before starting to return the records.
        :param str order: Order by event_time of events retrieved.
        :param list[str] severities: Retrieved events severities.
        :param str message: Retrieved events message pattern.
        :param bool deleted_hosts: Deleted hosts flag.
        :param bool cluster_level: Cluster level events flag.
        :param list[str] categories: A comma-separated list of event categories.
        :return: EventList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.v2_list_events_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.v2_list_events_with_http_info(**kwargs)  # noqa: E501
            return data

    def v2_list_events_with_http_info(self, **kwargs):  # noqa: E501
        """v2_list_events  # noqa: E501

        Lists events for a cluster.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v2_list_events_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cluster_id: The cluster to return events for.
        :param str host_id: A host in the specified cluster to return events for (DEPRECATED. Use `host_ids` instead).
        :param list[str] host_ids: Hosts in the specified cluster to return events for.
        :param str infra_env_id: The infra-env to return events for.
        :param int limit: The maximum number of records to retrieve.
        :param int offset: Number of records to skip before starting to return the records.
        :param str order: Order by event_time of events retrieved.
        :param list[str] severities: Retrieved events severities.
        :param str message: Retrieved events message pattern.
        :param bool deleted_hosts: Deleted hosts flag.
        :param bool cluster_level: Cluster level events flag.
        :param list[str] categories: A comma-separated list of event categories.
        :return: EventList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cluster_id', 'host_id', 'host_ids', 'infra_env_id', 'limit', 'offset', 'order', 'severities', 'message', 'deleted_hosts', 'cluster_level', 'categories']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v2_list_events" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'cluster_id' in params:
            query_params.append(('cluster_id', params['cluster_id']))  # noqa: E501
        if 'host_id' in params:
            query_params.append(('host_id', params['host_id']))  # noqa: E501
        if 'host_ids' in params:
            query_params.append(('host_ids', params['host_ids']))  # noqa: E501
            collection_formats['host_ids'] = 'csv'  # noqa: E501
        if 'infra_env_id' in params:
            query_params.append(('infra_env_id', params['infra_env_id']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'order' in params:
            query_params.append(('order', params['order']))  # noqa: E501
        if 'severities' in params:
            query_params.append(('severities', params['severities']))  # noqa: E501
            collection_formats['severities'] = 'csv'  # noqa: E501
        if 'message' in params:
            query_params.append(('message', params['message']))  # noqa: E501
        if 'deleted_hosts' in params:
            query_params.append(('deleted_hosts', params['deleted_hosts']))  # noqa: E501
        if 'cluster_level' in params:
            query_params.append(('cluster_level', params['cluster_level']))  # noqa: E501
        if 'categories' in params:
            query_params.append(('categories', params['categories']))  # noqa: E501
            collection_formats['categories'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['urlAuth', 'userAuth', 'watcherAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v2/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EventList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def v2_trigger_event(self, trigger_event_params, **kwargs):  # noqa: E501
        """v2_trigger_event  # noqa: E501

        Add new assisted installer event.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v2_trigger_event(trigger_event_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Event trigger_event_params: The event to be created. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.v2_trigger_event_with_http_info(trigger_event_params, **kwargs)  # noqa: E501
        else:
            (data) = self.v2_trigger_event_with_http_info(trigger_event_params, **kwargs)  # noqa: E501
            return data

    def v2_trigger_event_with_http_info(self, trigger_event_params, **kwargs):  # noqa: E501
        """v2_trigger_event  # noqa: E501

        Add new assisted installer event.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v2_trigger_event_with_http_info(trigger_event_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Event trigger_event_params: The event to be created. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trigger_event_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v2_trigger_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'trigger_event_params' is set
        if ('trigger_event_params' not in params or
                params['trigger_event_params'] is None):
            raise ValueError("Missing the required parameter `trigger_event_params` when calling `v2_trigger_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'trigger_event_params' in params:
            body_params = params['trigger_event_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['agentAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v2/events', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Manifest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'folder': 'str',
        'file_name': 'str',
        'manifest_source': 'str'
    }

    attribute_map = {
        'folder': 'folder',
        'file_name': 'file_name',
        'manifest_source': 'manifest_source'
    }

    def __init__(self, folder=None, file_name=None, manifest_source=None):  # noqa: E501
        """Manifest - a model defined in Swagger"""  # noqa: E501

        self._folder = None
        self._file_name = None
        self._manifest_source = None
        self.discriminator = None

        if folder is not None:
            self.folder = folder
        if file_name is not None:
            self.file_name = file_name
        if manifest_source is not None:
            self.manifest_source = manifest_source

    @property
    def folder(self):
        """Gets the folder of this Manifest.  # noqa: E501

        The folder that contains the files. Manifests can be placed in 'manifests' or 'openshift' directories.  # noqa: E501

        :return: The folder of this Manifest.  # noqa: E501
        :rtype: str
        """
        return self._folder

    @folder.setter
    def folder(self, folder):
        """Sets the folder of this Manifest.

        The folder that contains the files. Manifests can be placed in 'manifests' or 'openshift' directories.  # noqa: E501

        :param folder: The folder of this Manifest.  # noqa: E501
        :type: str
        """
        allowed_values = ["manifests", "openshift"]  # noqa: E501
        if folder not in allowed_values:
            raise ValueError(
                "Invalid value for `folder` ({0}), must be one of {1}"  # noqa: E501
                .format(folder, allowed_values)
            )

        self._folder = folder

    @property
    def file_name(self):
        """Gets the file_name of this Manifest.  # noqa: E501

        The file name prefaced by the folder that contains it.  # noqa: E501

        :return: The file_name of this Manifest.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this Manifest.

        The file name prefaced by the folder that contains it.  # noqa: E501

        :param file_name: The file_name of this Manifest.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def manifest_source(self):
        """Gets the manifest_source of this Manifest.  # noqa: E501

        Describes whether manifest is sourced from a user or created by the system.  # noqa: E501

        :return: The manifest_source of this Manifest.  # noqa: E501
        :rtype: str
        """
        return self._manifest_source

    @manifest_source.setter
    def manifest_source(self, manifest_source):
        """Sets the manifest_source of this Manifest.

        Describes whether manifest is sourced from a user or created by the system.  # noqa: E501

        :param manifest_source: The manifest_source of this Manifest.  # noqa: E501
        :type: str
        """
        allowed_values = ["user", "system"]  # noqa: E501
        if manifest_source not in allowed_values:
            raise ValueError(
                "Invalid value for `manifest_source` ({0}), must be one of {1}"  # noqa: E501
                .format(manifest_source, allowed_values)
            )

        self._manifest_source = manifest_source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Manifest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Manifest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DomainResolutionResponseResolutions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'domain_name': 'str',
        'ipv4_addresses': 'list[str]',
        'ipv6_addresses': 'list[str]',
        'cnames': 'list[str]'
    }

    attribute_map = {
        'domain_name': 'domain_name',
        'ipv4_addresses': 'ipv4_addresses',
        'ipv6_addresses': 'ipv6_addresses',
        'cnames': 'cnames'
    }

    def __init__(self, domain_name=None, ipv4_addresses=None, ipv6_addresses=None, cnames=None):  # noqa: E501
        """DomainResolutionResponseResolutions - a model defined in Swagger"""  # noqa: E501

        self._domain_name = None
        self._ipv4_addresses = None
        self._ipv6_addresses = None
        self._cnames = None
        self.discriminator = None

        self.domain_name = domain_name
        if ipv4_addresses is not None:
            self.ipv4_addresses = ipv4_addresses
        if ipv6_addresses is not None:
            self.ipv6_addresses = ipv6_addresses
        if cnames is not None:
            self.cnames = cnames

    @property
    def domain_name(self):
        """Gets the domain_name of this DomainResolutionResponseResolutions.  # noqa: E501

        The domain that was resolved  # noqa: E501

        :return: The domain_name of this DomainResolutionResponseResolutions.  # noqa: E501
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """Sets the domain_name of this DomainResolutionResponseResolutions.

        The domain that was resolved  # noqa: E501

        :param domain_name: The domain_name of this DomainResolutionResponseResolutions.  # noqa: E501
        :type: str
        """
        if domain_name is None:
            raise ValueError("Invalid value for `domain_name`, must not be `None`")  # noqa: E501

        self._domain_name = domain_name

    @property
    def ipv4_addresses(self):
        """Gets the ipv4_addresses of this DomainResolutionResponseResolutions.  # noqa: E501

        The IPv4 addresses of the domain, empty if none  # noqa: E501

        :return: The ipv4_addresses of this DomainResolutionResponseResolutions.  # noqa: E501
        :rtype: list[str]
        """
        return self._ipv4_addresses

    @ipv4_addresses.setter
    def ipv4_addresses(self, ipv4_addresses):
        """Sets the ipv4_addresses of this DomainResolutionResponseResolutions.

        The IPv4 addresses of the domain, empty if none  # noqa: E501

        :param ipv4_addresses: The ipv4_addresses of this DomainResolutionResponseResolutions.  # noqa: E501
        :type: list[str]
        """

        self._ipv4_addresses = ipv4_addresses

    @property
    def ipv6_addresses(self):
        """Gets the ipv6_addresses of this DomainResolutionResponseResolutions.  # noqa: E501

        The IPv6 addresses of the domain, empty if none  # noqa: E501

        :return: The ipv6_addresses of this DomainResolutionResponseResolutions.  # noqa: E501
        :rtype: list[str]
        """
        return self._ipv6_addresses

    @ipv6_addresses.setter
    def ipv6_addresses(self, ipv6_addresses):
        """Sets the ipv6_addresses of this DomainResolutionResponseResolutions.

        The IPv6 addresses of the domain, empty if none  # noqa: E501

        :param ipv6_addresses: The ipv6_addresses of this DomainResolutionResponseResolutions.  # noqa: E501
        :type: list[str]
        """

        self._ipv6_addresses = ipv6_addresses

    @property
    def cnames(self):
        """Gets the cnames of this DomainResolutionResponseResolutions.  # noqa: E501

        The cnames that were resolved for the domain, empty if none  # noqa: E501

        :return: The cnames of this DomainResolutionResponseResolutions.  # noqa: E501
        :rtype: list[str]
        """
        return self._cnames

    @cnames.setter
    def cnames(self, cnames):
        """Sets the cnames of this DomainResolutionResponseResolutions.

        The cnames that were resolved for the domain, empty if none  # noqa: E501

        :param cnames: The cnames of this DomainResolutionResponseResolutions.  # noqa: E501
        :type: list[str]
        """

        self._cnames = cnames

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DomainResolutionResponseResolutions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainResolutionResponseResolutions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
